@@ -1,4 +1,5 @@
 import re
+from pathlib import Path
 from typing import TypedDict, Iterator
 
 
@@ -8,6 +9,12 @@ class CanvasResource(TypedDict):
     data: dict | None
 
 
+class CourseSettings(TypedDict):
+    name: str
+    code: str
+    image: str
+
+
 class FileData(TypedDict):
     path: str
     canvas_folder: str | None
